@@ -5,10 +5,9 @@
 # 2024 Translated from MATLAB to Python by U.A. Canbolat <utku.canbolat@fau.de>
 
 import sys
-sys.path.append('/home/vas/Desktop/Utku_Code_Review/CLUMP_Python/')
 
 import numpy as np
-from CLUMP.ExtractSurface import ExtractSurface
+from CLUMP import ExtractSurface
 from CLUMP.utils.STL_ReaderWriter import write_stl
 
 clump = np.array([[1, 0, 0, 1.1],
@@ -22,4 +21,4 @@ visualise = True
 
 faces, vertices = ExtractSurface(clump, N_sphere, N_circle, visualise)
 
-write_stl('Particle_surface.stl',vertices,faces)
+write_stl('Particle_surface.stl', vertices, faces)
