@@ -5,11 +5,10 @@
 # 2024 Translated from MATLAB to Python by U.A. Canbolat <utku.canbolat@fau.de>
 
 import sys
-sys.path.append('/home/vas/Desktop/Utku_Code_Review/CLUMP_Python/')
 
-from CLUMP.GenerateClump_Favier import GenerateClump_Favier
+from CLUMP import GenerateClump_Favier
 import sys
-sys.path.append('../')
+sys.path.append('../../')
 
 inputGeom = 'ParticleGeometries/Ellipsoid_R_2.0_1.0_1.0.stl'
 N = 10
